Class: SkillBench::Cli::ResultPrinter
- Inherits:
-
Object
- Object
- SkillBench::Cli::ResultPrinter
- Defined in:
- lib/skill_bench/cli/result_printer.rb
Overview
Prints the result of a ‘skill-bench run` command.
Class Method Summary collapse
-
.call(result, format: :human) ⇒ Integer
Prints the result and returns the appropriate exit code.
Class Method Details
.call(result, format: :human) ⇒ Integer
Prints the result and returns the appropriate exit code.
14 15 16 17 |
# File 'lib/skill_bench/cli/result_printer.rb', line 14 def self.call(result, format: :human) puts OutputFormatter.format(result, format: format) OutputFormatter.exit_code(result) end |