Class: SkillBench::Clients::Providers::Gemini

Inherits:
BaseClient
  • Object
show all
Defined in:
lib/skill_bench/clients/providers/gemini.rb

Overview

Google Gemini provider using the OpenAI-compatible Vertex AI endpoint.

This client handles the authentication and routing for Google’s Vertex AI OpenAI-compatible API, allowing it to be used alongside other providers.

Instance Attribute Summary

Attributes inherited from BaseClient

#api_key, #messages, #model, #options, #system_prompt, #tools

Instance Method Summary collapse

Methods inherited from BaseClient

call, #call, #initialize

Constructor Details

This class inherits a constructor from SkillBench::Clients::BaseClient

Instance Method Details

#provider_nameSymbol

Returns the provider identifier.

Returns:

  • (Symbol)


22
23
24
# File 'lib/skill_bench/clients/providers/gemini.rb', line 22

def provider_name
  :gemini
end