Class: SkillBench::Cli::HelpPrinter
- Inherits:
-
Object
- Object
- SkillBench::Cli::HelpPrinter
- Defined in:
- lib/skill_bench/cli/help_printer.rb
Overview
Prints the CLI help/usage message.
Class Method Summary collapse
-
.call ⇒ Integer
Prints the help message and returns exit code 0.
Class Method Details
.call ⇒ Integer
Prints the help message and returns exit code 0.
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/skill_bench/cli/help_printer.rb', line 10 def self.call providers = SkillBench::Clients::ProviderSchemas.names.map { |name| "--#{name}" }.join(', ') puts <<~USAGE Usage: skill-bench <subcommand> [options] Subcommands: init --<provider> [--force] Generate configuration file Providers: #{providers} --force Overwrite existing config file run <eval> --skill <name> [--skill <name>] [--format FORMAT] Run an evaluation --skill Skill to use (can be specified multiple times) --format Output format: human, json, junit (default: human) skill new <name> [--mode MODE] [--template TYPE] Create a new skill --mode simple, advanced, or rails (default: simple) --template service_object, concern, active_record_model (default: service_object) eval new <name> [--runtime TYPE] Create a new eval --runtime rails, ruby, etc. (default: ruby) eval generate <skill-name> [--name <eval-name>] Auto-generate an eval from a skill --name Name for the generated eval (optional) Global Options: -h, --help Show this help message USAGE 0 end |