Class: SkillBench::Clients::Providers::OpenCode
- Inherits:
-
BaseClient
- Object
- BaseClient
- SkillBench::Clients::Providers::OpenCode
- Defined in:
- lib/skill_bench/clients/providers/opencode.rb
Overview
OpenCode provider client.
IMPORTANT: OpenCode does not host a public LLM API. This provider is a thin wrapper around an OpenAI-compatible endpoint that YOU provide (e.g. LiteLLM proxy, vLLM, or a company gateway). You MUST set ‘base_url` in `skill-bench.json` or via the `SKILL_BENCH_OPENCODE_BASE_URL` environment variable, otherwise the provider will fail with “Base URL not set for Opencode”.
Instance Attribute Summary
Attributes inherited from BaseClient
#api_key, #messages, #model, #options, #system_prompt, #tools
Instance Method Summary collapse
-
#provider_name ⇒ Symbol
Returns the provider identifier.
Methods inherited from BaseClient
Constructor Details
This class inherits a constructor from SkillBench::Clients::BaseClient
Instance Method Details
#provider_name ⇒ Symbol
Returns the provider identifier.
22 23 24 |
# File 'lib/skill_bench/clients/providers/opencode.rb', line 22 def provider_name :opencode end |