Class: SkillBench::EvaluateCommand Deprecated
- Inherits:
-
Object
- Object
- SkillBench::EvaluateCommand
- Defined in:
- lib/skill_bench/evaluate_command.rb
Overview
Deprecated.
Use Cli::RunCommand and Services::RunnerService instead.
Implements the ‘skill-bench run` CLI command. Orchestrates option parsing, evaluation execution, result printing, and output persistence.
Class Method Summary collapse
-
.call(argv, stdout: $stdout) ⇒ Integer
Parses arguments, runs the evaluator, prints the report, and records history.
Instance Method Summary collapse
-
#call ⇒ Integer
Executes the command by orchestrating service objects.
-
#initialize(argv, stdout:) ⇒ EvaluateCommand
constructor
A new instance of EvaluateCommand.
Constructor Details
#initialize(argv, stdout:) ⇒ EvaluateCommand
Returns a new instance of EvaluateCommand.
27 28 29 30 31 |
# File 'lib/skill_bench/evaluate_command.rb', line 27 def initialize(argv, stdout:) @argv = argv @stdout = stdout @options = nil end |
Class Method Details
.call(argv, stdout: $stdout) ⇒ Integer
Parses arguments, runs the evaluator, prints the report, and records history.
21 22 23 |
# File 'lib/skill_bench/evaluate_command.rb', line 21 def self.call(argv, stdout: $stdout) new(argv, stdout: stdout).call end |
Instance Method Details
#call ⇒ Integer
Executes the command by orchestrating service objects.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/skill_bench/evaluate_command.rb', line 38 def call return 1 unless && result = run_evaluation return 1 unless result[:success] return 1 unless persist_output?(result) SkillBench::HistoryRecorder.record( result, source_path: result[:source_path], model: SkillBench::Config.model ) 0 end |