Module: SkillBench::Tools
- Defined in:
- lib/skill_bench/tools.rb,
lib/skill_bench/tools/base.rb,
lib/skill_bench/tools/registry.rb,
lib/skill_bench/tools/read_file.rb,
lib/skill_bench/tools/dispatcher.rb,
lib/skill_bench/tools/write_file.rb,
lib/skill_bench/tools/run_command.rb,
lib/skill_bench/tools/argument_parser.rb
Overview
Contains tool implementations for the evaluator.
Defined Under Namespace
Classes: ArgumentParser, Base, Dispatcher, ReadFile, Registry, RunCommand, WriteFile
Class Method Summary collapse
-
.definitions ⇒ Array<Hash>
Returns an array of tool definitions in the format expected by the LLM API.
-
.execute(name, arguments, working_dir, container_id = nil) ⇒ String
Executes a specified tool with the given arguments within a working directory.
Class Method Details
.definitions ⇒ Array<Hash>
Returns an array of tool definitions in the format expected by the LLM API.
18 19 20 |
# File 'lib/skill_bench/tools.rb', line 18 def self.definitions Registry.definitions end |
.execute(name, arguments, working_dir, container_id = nil) ⇒ String
Executes a specified tool with the given arguments within a working directory.
29 30 31 |
# File 'lib/skill_bench/tools.rb', line 29 def self.execute(name, arguments, working_dir, container_id = nil) Dispatcher.call(name, arguments, working_dir, container_id) end |